# camazing

Easy-to-use machine vision library for GenICam-compliant cameras.

## Features

 * Fully Pythonic operation (no messing with C structures)
 * Data acquisition (with rich metadata for scientific use cases)
 * Advanced camera setting control (including saving and loading settings, proper checks for valid values, etc.)
 * Free software (MIT licensed)

## Getting started

See the documentation at https://camazing.readthedocs.io.
